@@ -12,7 +12,7 @@ inherit from it.
 package HTML::Microformats::Format;
 
 use base qw(HTML::Microformats::Mixin::RDF);
-use common::sense;
+use strict qw(subs vars); no warnings;
 use 5.010;
 
 use Carp;
@@ -24,7 +24,7 @@ use Object::AUTHORITY;
 
 BEGIN {
 	$HTML::Microformats::Format::AUTHORITY = 'cpan:TOBYINK';
-	$HTML::Microformats::Format::VERSION   = '0.104';
+	$HTML::Microformats::Format::VERSION   = '0.105';
 }
 our $AUTOLOAD;
 
@@ -429,9 +429,9 @@ L<HTML::Microformats>.
 
 Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENCE
 
-Copyright 2008-2011 Toby Inkster
+Copyright 2008-2012 Toby Inkster
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
