@@ -22,14 +22,14 @@ constructors, etc.
 package HTML::Microformats::Format::RelLicense;
 
 use base qw(HTML::Microformats::Format_Rel);
-use common::sense;
+use strict qw(subs vars); no warnings;
 use 5.010;
 
 use Object::AUTHORITY;
 
 BEGIN {
 	$HTML::Microformats::Format::RelLicense::AUTHORITY = 'cpan:TOBYINK';
-	$HTML::Microformats::Format::RelLicense::VERSION   = '0.104';
+	$HTML::Microformats::Format::RelLicense::VERSION   = '0.105';
 }
 
 sub format_signature
@@ -112,9 +112,9 @@ L<HTML::Microformats>.
 
 Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENCE
 
-Copyright 2008-2011 Toby Inkster
+Copyright 2008-2012 Toby Inkster
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
