@@ -44,7 +44,7 @@ the tagspace is "http://example.com/foo/".
 package HTML::Microformats::Format::RelTag;
 
 use base qw(HTML::Microformats::Format_Rel);
-use common::sense;
+use strict qw(subs vars); no warnings;
 use 5.010;
 
 use CGI::Util qw(unescape);
@@ -53,7 +53,7 @@ use Object::AUTHORITY;
 
 BEGIN {
 	$HTML::Microformats::Format::RelTag::AUTHORITY = 'cpan:TOBYINK';
-	$HTML::Microformats::Format::RelTag::VERSION   = '0.104';
+	$HTML::Microformats::Format::RelTag::VERSION   = '0.105';
 }
 
 sub new
@@ -153,9 +153,9 @@ L<HTML::Microformats::Format::hAtom>.
 
 Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENCE
 
-Copyright 2008-2011 Toby Inkster
+Copyright 2008-2012 Toby Inkster
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
