@@ -40,14 +40,14 @@ the C<data> method returns the same structure.
 package HTML::Microformats::Format::XMDP;
 
 use base qw(HTML::Microformats::Format::XOXO);
-use common::sense;
+use strict qw(subs vars); no warnings;
 use 5.010;
 
 use Object::AUTHORITY;
 
 BEGIN {
 	$HTML::Microformats::Format::XMDP::AUTHORITY = 'cpan:TOBYINK';
-	$HTML::Microformats::Format::XMDP::VERSION   = '0.104';
+	$HTML::Microformats::Format::XMDP::VERSION   = '0.105';
 }
 
 sub new
@@ -176,9 +176,9 @@ L<HTML::Microformats>.
 
 Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENCE
 
-Copyright 2008-2011 Toby Inkster
+Copyright 2008-2012 Toby Inkster
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
