@@ -27,7 +27,7 @@ constructors, etc.
 package HTML::Microformats::Format::adr;
 
 use base qw(HTML::Microformats::Format HTML::Microformats::Mixin::Parser);
-use common::sense;
+use strict qw(subs vars); no warnings;
 use 5.010;
 
 use Locale::Country qw(country2code LOCALE_CODE_ALPHA_2);
@@ -36,7 +36,7 @@ use Object::AUTHORITY;
 
 BEGIN {
 	$HTML::Microformats::Format::adr::AUTHORITY = 'cpan:TOBYINK';
-	$HTML::Microformats::Format::adr::VERSION   = '0.104';
+	$HTML::Microformats::Format::adr::VERSION   = '0.105';
 }
 
 sub new
@@ -236,9 +236,9 @@ L<HTML::Microformats::Format::geo>.
 
 Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENCE
 
-Copyright 2008-2011 Toby Inkster
+Copyright 2008-2012 Toby Inkster
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
