@@ -38,7 +38,7 @@ and will throw an error at run-time if it's not available.
 package HTML::Microformats::Format::geo;
 
 use base qw(HTML::Microformats::Format HTML::Microformats::Mixin::Parser);
-use common::sense;
+use strict qw(subs vars); no warnings;
 use 5.010;
 
 use HTML::Microformats::Utilities qw(stringify);
@@ -47,7 +47,7 @@ use Object::AUTHORITY;
 
 BEGIN {
 	$HTML::Microformats::Format::geo::AUTHORITY = 'cpan:TOBYINK';
-	$HTML::Microformats::Format::geo::VERSION   = '0.104';
+	$HTML::Microformats::Format::geo::VERSION   = '0.105';
 }
 our $HAS_KML_EXPORT;
 BEGIN
@@ -312,9 +312,9 @@ L<HTML::Microformats::Format::hCard>.
 
 Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENCE
 
-Copyright 2008-2011 Toby Inkster
+Copyright 2008-2012 Toby Inkster
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
