@@ -52,7 +52,7 @@ if it's not available.
 package HTML::Microformats::Format::hEntry;
 
 use base qw(HTML::Microformats::Format HTML::Microformats::Mixin::Parser);
-use common::sense;
+use strict qw(subs vars); no warnings;
 use 5.010;
 
 use HTML::Microformats::Utilities qw(searchClass searchAncestorClass stringify);
@@ -65,7 +65,7 @@ use Object::AUTHORITY;
 
 BEGIN {
 	$HTML::Microformats::Format::hEntry::AUTHORITY = 'cpan:TOBYINK';
-	$HTML::Microformats::Format::hEntry::VERSION   = '0.104';
+	$HTML::Microformats::Format::hEntry::VERSION   = '0.105';
 }
 our $HAS_ATOM_EXPORT;
 BEGIN
@@ -684,9 +684,9 @@ L<HTML::Microformats::Format::hNews>.
 
 Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENCE
 
-Copyright 2008-2011 Toby Inkster
+Copyright 2008-2012 Toby Inkster
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
