@@ -46,7 +46,7 @@ if it's not available.
 package HTML::Microformats::Format::hEvent;
 
 use base qw(HTML::Microformats::Format HTML::Microformats::Mixin::Parser);
-use common::sense;
+use strict qw(subs vars); no warnings;
 use 5.010;
 
 use HTML::Microformats::Utilities qw(searchClass searchRel stringify);
@@ -57,7 +57,7 @@ use Object::AUTHORITY;
 
 BEGIN {
 	$HTML::Microformats::Format::hEvent::AUTHORITY = 'cpan:TOBYINK';
-	$HTML::Microformats::Format::hEvent::VERSION   = '0.104';
+	$HTML::Microformats::Format::hEvent::VERSION   = '0.105';
 }
 
 sub new
@@ -425,9 +425,9 @@ L<HTML::Microformats>.
 
 Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENCE
 
-Copyright 2008-2011 Toby Inkster
+Copyright 2008-2012 Toby Inkster
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
