@@ -26,7 +26,7 @@ constructors, etc.
 package HTML::Microformats::Format::hListing;
 
 use base qw(HTML::Microformats::Format::hReview);
-use common::sense;
+use strict qw(subs vars); no warnings;
 use 5.010;
 
 use HTML::Microformats::Utilities qw(searchClass);
@@ -35,7 +35,7 @@ use Object::AUTHORITY;
 
 BEGIN {
 	$HTML::Microformats::Format::hListing::AUTHORITY = 'cpan:TOBYINK';
-	$HTML::Microformats::Format::hListing::VERSION   = '0.104';
+	$HTML::Microformats::Format::hListing::VERSION   = '0.105';
 }
 
 sub new
@@ -287,9 +287,9 @@ L<HTML::Microformats>.
 
 Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENCE
 
-Copyright 2008-2011 Toby Inkster
+Copyright 2008-2012 Toby Inkster
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
