@@ -26,7 +26,7 @@ constructors, etc.
 package HTML::Microformats::Format::hNews;
 
 use base qw(HTML::Microformats::Format::hEntry);
-use common::sense;
+use strict qw(subs vars); no warnings;
 use 5.010;
 
 use HTML::Microformats::Utilities qw(searchClass);
@@ -36,7 +36,7 @@ use Object::AUTHORITY;
 
 BEGIN {
 	$HTML::Microformats::Format::hNews::AUTHORITY = 'cpan:TOBYINK';
-	$HTML::Microformats::Format::hNews::VERSION   = '0.104';
+	$HTML::Microformats::Format::hNews::VERSION   = '0.105';
 }
 
 sub new
@@ -188,9 +188,9 @@ L<HTML::Microformats::Format::hEntry>.
 
 Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENCE
 
-Copyright 2008-2011 Toby Inkster
+Copyright 2008-2012 Toby Inkster
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
